#!/usr/bin/env python3

import argparse as ap

import shared


ACTIONS = dict()


def action(key):
    def wrapper(function):
        ACTIONS[key] = function
        return function
    return wrapper


def get_closed_issues(repo, milestone):
    issues_and_prs = repo.get_issues(milestone=milestone, state="closed")
    issues_only = [i for i in issues_and_prs if i.pull_request is None]
    return issues_only


def get_closed_prs(repo, milestone):
    issues_and_prs = repo.get_issues(milestone=milestone, state="closed")
    prs_only = [i for i in issues_and_prs if i.pull_request is not None]
    return prs_only


@action("issues-closed")
def print_closed_issues(repo, milestone):
    for issue in get_closed_issues(repo, milestone):
        print(issue.title)


@action("prs-merged")
def print_closed_prs(repo, milestone):
    for pr in get_closed_prs(repo, milestone):
        print(pr.title)


def create_parser():
    parser = ap.ArgumentParser()
    parser.add_argument("version", type=shared.version_type)
    parser.add_argument("what", choices=(ACTIONS.keys()))
    shared.update_parser_with_common_stuff(parser)
    return parser


if __name__ == "__main__":
    parser = create_parser()
    args = parser.parse_args()
    gh = shared.get_github(args)
    repo = shared.get_repo(gh, "OpenSCAP")

    milestone = shared.get_milestone(repo, args.version)
    ACTIONS[args.what](repo, milestone)



# This is a template for D-Bus mock
# see init_dbus_mock() from test_common.sh.
# The Exit() method is expected by
# clean_dbus_mock() from the same file.

__author__ = 'Evgenii Kolesnikov'
__copyright__ = '''
(c) 2023 Red Hat Inc.
'''

import dbus


BUS_NAME = 'org.freedesktop.fwupd'
MAIN_OBJ = '/'
MAIN_IFACE = 'org.freedesktop.fwupd'
SYSTEM_BUS = False


def load(mock, _parameters):
    mock.AddMethods(MAIN_IFACE, [
        ('GetHostSecurityAttrs', '', 'aa{sv}', 'ret = self.SecurityAattrs'),
        ('Exit', '', '', 'sys.exit()'),
    ])

    mock.SecurityAattrs = [
        {
            'AppstreamId': 'org.fwupd.hsi.Kernel.Lockdown', 'HsiResult': dbus.UInt32(2)
        },
        {
            'AppstreamId': 'org.fwupd.hsi.Kernel.InvalidStatus', 'HsiResult': dbus.UInt32(200)
        }
    ]



#!/usr/bin/env python

# Author:
#   Dominique Blaze <contact@d0m.tech>
#
# This test aims to verify if xccdf_session works well with
# the xccdf_session_set_rule call.
#

import os
from import_handler import oscap, result2str, get_path

# ======================     Part 1   ============================

print("opening ./samples/xccdf_sample.xml ...")
sess = oscap.xccdf.session_new(get_path("samples/xccdf_sample.xml"))

res = sess.load()

''' rules to test which desired return value in this format:
    (rule_name, expected_result_id, expected_base_score)
'''

rules = (("R-SHOULD_PASS", oscap.common.XCCDF_RESULT_PASS, 100),
         ("R-SHOULD_FAIL", oscap.common.XCCDF_RESULT_FAIL, 0))

for rule in rules:
    print("evaluating rule {0}".format(rule[0]))
    sess.set_rule(rule[0])

    if not res == 0:
        raise ValueError("Return value of xccdf_session_load isn't 0 but {0} !".format(res))

    res = sess.evaluate()

    if not res == 0:
        raise ValueError("Return value of xccdf_session_evaluate isn't 0 but {0} !".format(res))

    if sess.get_base_score() != rule[2]:
        print("base score for {0} should be {1} but is {2} "
              .format(rule[0], rule[2], sess.get_base_score()))

    rs = sess.get_xccdf_policy().get_results()[-1]  # get last value

    rr = sess.get_rule_result(rule[0])

    print("Result = {0}".format(result2str(rr.get_result())))
    if rule[1] != rr.get_result():
        raise ValueError("Result value of {0} should be {1} but is {2}"
                         .format(rule[0], rule[1], rr.get_result()))

# release session
sess.free()



import importlib
import pathlib
import json

import pytest

NS = "http://checklists.nist.gov/xccdf/1.2"


def import_arbitrary_file_as_module(path, module_name):
    spec = importlib.util.spec_from_loader(
        module_name, importlib.machinery.SourceFileLoader(module_name, path))
    module = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(module)
    return module


autotailor = import_arbitrary_file_as_module("../../../utils/autotailor", "autotailor")


def test_is_valid_xccdf_id():
    assert autotailor.is_valid_xccdf_id(
        "xccdf_com.example.www_profile_abcd")
    assert autotailor.is_valid_xccdf_id(
        "xccdf_com.example.www_rule_selinux_state")
    assert not autotailor.is_valid_xccdf_id("")
    assert not autotailor.is_valid_xccdf_id("foo")
    assert not autotailor.is_valid_xccdf_id(
        "xccdf_com_example_www_rule_selinux_state")
    assert not autotailor.is_valid_xccdf_id("xccdf_rule_selinux_state")
    assert not autotailor.is_valid_xccdf_id("xccdf_com.example.www_rule_")


def test_full_id():
    p = autotailor.Profile()
    assert p._full_rule_id("accounts_tmout") == \
        "xccdf_org.ssgproject.content_rule_accounts_tmout"
    assert p._full_rule_id(
        "xccdf_org.ssgproject.content_rule_accounts_tmout") == \
        "xccdf_org.ssgproject.content_rule_accounts_tmout"
    assert p._full_profile_id("stig") == \
        "xccdf_org.ssgproject.content_profile_stig"
    assert p._full_profile_id(
        "xccdf_org.ssgproject.content_profile_stig") == \
        "xccdf_org.ssgproject.content_profile_stig"
    assert p._full_var_id("var_crypto_policy") == \
        "xccdf_org.ssgproject.content_value_var_crypto_policy"
    assert p._full_var_id(
        "xccdf_org.ssgproject.content_value_var_crypto_policy") == \
        "xccdf_org.ssgproject.content_value_var_crypto_policy"


def test_customized_profile_id():
    p = autotailor.Profile()
    p.extends = "stig"
    assert p.profile_id == "stig_customized"
    p.profile_id = "my_cool_profile"
    assert p.profile_id == "my_cool_profile"


def test_refine_rule():
    p = autotailor.Profile()
    with pytest.raises(ValueError) as e:
        p.refine_rule("selinux_state", "severity", "high")
    assert str(e.value) == "Rule id 'selinux_state' is invalid!"
    with pytest.raises(ValueError) as e:
        p.refine_rule(
            "xccdf_org.ssgproject.content_rule_accounts_tmout", "foo", "bar")
    assert str(e.value) == "Unsupported refine-rule attribute foo"
    with pytest.raises(ValueError) as e:
        p.refine_rule(
            "xccdf_org.ssgproject.content_rule_accounts_tmout",
            "role", "mnau")
    assert str(e.value) == (
        "Can't refine role of rule 'xccdf_org.ssgproject.content_rule_accounts"
        "_tmout' to 'mnau'. Allowed role values are: \"full\", \"unscored\", "
        "\"unchecked\".")
    with pytest.raises(ValueError) as e:
        p.refine_rule(
            "xccdf_org.ssgproject.content_rule_accounts_tmout",
            "severity", "mnau")
    assert str(e.value) == (
        "Can't refine severity of rule 'xccdf_org.ssgproject.content_rule_"
        "accounts_tmout' to 'mnau'. Allowed severity values are: \"unknown\", "
        "\"info\", \"low\", \"medium\", \"high\".")
    fav = "xccdf_org.ssgproject.content_rule_accounts_tmout"
    p.refine_rule(fav, "severity", "high")
    assert p.rule_refinements(fav, "severity") == "high"
    p.refine_rule(fav, "role", "full")
    assert p.rule_refinements(fav, "severity") == "high"
    assert p.rule_refinements(fav, "role") == "full"
    with pytest.raises(ValueError) as e:
        p.refine_rule(fav, "severity", "low")
    assert str(e.value) == (
        "Can't refine severity of rule 'xccdf_org.ssgproject.content_rule_"
        "accounts_tmout' to 'low'. This rule severity is already refined to "
        "'high'.")
    assert p.rule_refinements(fav, "severity") == "high"
    assert p.rule_refinements(fav, "role") == "full"

def test_no_id():
    p = autotailor.Profile()
    profile_dict = None
    file_path = pathlib.Path(__file__).parent.joinpath("custom_no_ids.json")
    with open(file_path) as fp:
        json_data = json.load(fp)
        profile_dict = json_data["profiles"][0]
    with pytest.raises(ValueError) as e:
        p.import_json_tailoring_profile(profile_dict)
    assert str(e.value) == "You must define a base_profile_id or an id"
